@@ -1,19 +1,8 @@
 /*
-  Copyright (C) 2017-2020 Laurent Montel <montel@kde.org>
-  Copyright (c) 2017 David Faure <faure@kde.org>
+  SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017 David Faure <faure@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "jobtrackertest.h"
@@ -24,7 +13,7 @@
 
 static QString intPairListToString(const QVariant &var)
 {
-    const auto arg = var.value<QList<QPair<int, int>>>();
+    const auto arg = var.value<QList<QPair<int, int> > >();
     QString ret;
     for (const auto &pair : arg) {
         if (!ret.isEmpty()) {
@@ -49,7 +38,7 @@ void JobTrackerTest::initTestCase()
     // Don't interfere with a running akonadiconsole
     Akonadi::Instance::setIdentifier(QStringLiteral("jobtrackertest"));
 
-    qRegisterMetaType<QList<QPair<int, int>>>();
+    qRegisterMetaType<QList<QPair<int, int> > >();
 }
 
 void JobTrackerTest::shouldBeEmpty()
