@@ -1,22 +1,9 @@
 /*
     This file is part of Akonadi.
 
-    Copyright (c) 2006 Tobias Koenig <tokoe@kde.org>
+    SPDX-FileCopyrightText: 2006 Tobias Koenig <tokoe@kde.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-    USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "connectionpage.h"
@@ -39,9 +26,11 @@
 Q_DECLARE_METATYPE(DebugModel::Message)
 
 ConnectionPage::ConnectionPage(const QString &identifier, QWidget *parent)
-    : QWidget(parent), mIdentifier(identifier), mShowAllConnections(false)
+    : QWidget(parent)
+    , mIdentifier(identifier)
+    , mShowAllConnections(false)
 {
-    QVBoxLayout *layout = new QVBoxLayout(this);
+    auto *layout = new QVBoxLayout(this);
     auto h = new QHBoxLayout;
     layout->addLayout(h);
 
@@ -50,7 +39,7 @@ ConnectionPage::ConnectionPage(const QString &identifier, QWidget *parent)
     h->setStretchFactor(mSenderFilter, 2);
 
     mModel = new DebugModel(this);
-    mModel->setSenderFilterModel(qobject_cast<QStandardItemModel*>(mSenderFilter->model()));
+    mModel->setSenderFilterModel(qobject_cast<QStandardItemModel *>(mSenderFilter->model()));
 
     mFilterModel = new DebugFilterModel(this);
     mFilterModel->setSourceModel(mModel);
@@ -101,13 +90,12 @@ QString ConnectionPage::toHtml(QAbstractItemModel *model) const
 {
     QString ret;
     int anz = model->rowCount();
-    for (int row=0; row < anz; row++) {
+    for (int row = 0; row < anz; row++) {
         const auto message = model->data(model->index(row, 0), DebugModel::MessageRole).value<DebugModel::Message>();
         const auto &sender = model->data(model->index(row, DebugModel::SenderColumn)).toString();
 
-        ret += (message.direction==DebugModel::ClientToServer ? QStringLiteral("<- ") : QStringLiteral("-> "));
+        ret += (message.direction == DebugModel::ClientToServer ? QStringLiteral("<- ") : QStringLiteral("-> "));
         ret += sender + QStringLiteral(" ") + message.message + QStringLiteral("\n");
-
     }
     return ret;
 }
