@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2009 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2009 Volker Krause <vkrause@kde.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-    USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "notificationmonitor.h"
@@ -22,7 +9,6 @@
 #include "notificationfiltermodel.h"
 #include "utils.h"
 
-#include <akonadi/private/protocol_p.h>
 #include <AkonadiWidgets/ControlGui>
 
 #include <QFileDialog>
@@ -51,8 +37,8 @@ using KPIM::KCheckComboBox;
 
 Q_DECLARE_METATYPE(Akonadi::ChangeNotification)
 
-NotificationMonitor::NotificationMonitor(QWidget *parent) :
-    QWidget(parent)
+NotificationMonitor::NotificationMonitor(QWidget *parent)
+    : QWidget(parent)
 {
     m_model = new NotificationModel(this);
     m_model->setEnabled(false);   // since it can be slow, default to off
@@ -60,11 +46,11 @@ NotificationMonitor::NotificationMonitor(QWidget *parent) :
     m_filterModel = new NotificationFilterModel(this);
     m_filterModel->setSourceModel(m_model);
 
-    QVBoxLayout *layout = new QVBoxLayout(this);
+    auto *layout = new QVBoxLayout(this);
     auto hLayout = new QHBoxLayout;
     layout->addLayout(hLayout);
 
-    QCheckBox *enableCB = new QCheckBox(this);
+    auto *enableCB = new QCheckBox(this);
     enableCB->setText(QStringLiteral("Enable notification monitor"));
     enableCB->setChecked(m_model->isEnabled());
     connect(enableCB, &QCheckBox::toggled, m_model, &NotificationModel::setEnabled);
@@ -122,7 +108,6 @@ NotificationMonitor::~NotificationMonitor()
     config.writeEntry("splitter", m_splitter->saveState());
 }
 
-
 void NotificationMonitor::contextMenu(const QPoint & /*pos*/)
 {
     QMenu menu;
@@ -140,7 +125,7 @@ void NotificationMonitor::onNotificationSelected(const QModelIndex &index)
 
 void NotificationMonitor::populateNtfModel(const QModelIndex &index)
 {
-    auto model = qobject_cast<QStandardItemModel*>(m_ntfView->model());
+    auto model = qobject_cast<QStandardItemModel *>(m_ntfView->model());
     model->clear();
     model->setHorizontalHeaderLabels({ QStringLiteral("Properties"), QStringLiteral("Values") });
 
@@ -224,16 +209,16 @@ void NotificationMonitor::populateItemNtfTree(QStandardItemModel *model, const A
     appendRow(model, QStringLiteral("Removed Flags"),
               toString(ntf.removedFlags()));
     appendRow(model, QStringLiteral("Added Tags"),
-              toString(ntf.addedTags()));;
+              toString(ntf.addedTags()));
     appendRow(model, QStringLiteral("Removed Tags"),
               toString(ntf.removedTags()));
     auto relationsItem = new QStandardItem(QStringLiteral("Added Relations"));
     const auto addedRelations = ntf.addedRelations();
     for (const auto &addedRelation : addedRelations) {
         auto item = new QStandardItem(QStringLiteral("%lld-%lld %s").arg(
-                    QString::number(addedRelation.leftId),
-                    QString::number(addedRelation.rightId),
-                    addedRelation.type));
+                                          QString::number(addedRelation.leftId),
+                                          QString::number(addedRelation.rightId),
+                                          addedRelation.type));
         relationsItem->appendRow(item);
     }
     model->appendRow(relationsItem);
@@ -242,9 +227,9 @@ void NotificationMonitor::populateItemNtfTree(QStandardItemModel *model, const A
     const auto removedRelations = ntf.removedRelations();
     for (const auto &removedRelation : removedRelations) {
         auto item = new QStandardItem(QStringLiteral("%lld-%lld %s").arg(
-                    QString::number(removedRelation.leftId),
-                    QString::number(removedRelation.rightId),
-                    removedRelation.type));
+                                          QString::number(removedRelation.leftId),
+                                          QString::number(removedRelation.rightId),
+                                          removedRelation.type));
         relationsItem->appendRow(item);
     }
     model->appendRow(relationsItem);
@@ -347,7 +332,7 @@ void NotificationMonitor::populateItemTree(QStandardItem *parent, const Akonadi:
         appendRow(item, QStringLiteral("Size"), QString::number(part.metaData().size()));
         appendRow(item, QStringLiteral("Storage Type"), type);
         appendRow(item, QStringLiteral("Version"), QString::number(part.metaData().version()));
-        appendRow(item, QStringLiteral("Data"), QString::fromUtf8( part.data().toHex()));
+        appendRow(item, QStringLiteral("Data"), QString::fromUtf8(part.data().toHex()));
 
         partsItem->appendRow(item);
     }
@@ -359,7 +344,7 @@ void NotificationMonitor::populateCollectionTree(QStandardItem *parent, const Ak
     appendRow(parent, QStringLiteral("ID"), QString::number(collection.id()));
     appendRow(parent, QStringLiteral("Parent ID"), QString::number(collection.parentId()));
     appendRow(parent, QStringLiteral("Name"), collection.name());
-    appendRow(parent, QStringLiteral("Mime Types"), toString(static_cast<QList<QString>>(collection.mimeTypes())));
+    appendRow(parent, QStringLiteral("Mime Types"), toString(static_cast<QList<QString> >(collection.mimeTypes())));
     appendRow(parent, QStringLiteral("Remote ID"), collection.remoteId());
     appendRow(parent, QStringLiteral("Remote Revision"), collection.remoteRevision());
     auto statsItem = new QStandardItem(QStringLiteral("Statistics"));
@@ -382,7 +367,7 @@ void NotificationMonitor::populateCollectionTree(QStandardItem *parent, const Ak
     appendRow(cpItem, QStringLiteral("Check Interval"), QString::number(cp.checkInterval()));
     appendRow(cpItem, QStringLiteral("Cache Timeout"), QString::number(cp.cacheTimeout()));
     appendRow(cpItem, QStringLiteral("Sync on Demand"), toString(cp.syncOnDemand()));
-    appendRow(cpItem, QStringLiteral("Local Parts"), toString(static_cast<QList<QString>>(cp.localParts())));
+    appendRow(cpItem, QStringLiteral("Local Parts"), toString(static_cast<QList<QString> >(cp.localParts())));
     parent->appendRow(cpItem);
 
     populateAttributesTree(parent, collection.attributes());
@@ -394,7 +379,6 @@ void NotificationMonitor::populateCollectionTree(QStandardItem *parent, const Ak
     appendRow(parent, QStringLiteral("Virtual"), toString(collection.isVirtual()));
 }
 
-
 void NotificationMonitor::populateCollectionNtfTree(QStandardItemModel *model, const Akonadi::Protocol::CollectionChangeNotification &ntf)
 {
     QString operation;
@@ -614,7 +598,7 @@ void NotificationMonitor::populateSubscriptionNtfTree(QStandardItemModel *model,
         break;
     }
     appendRow(item, QStringLiteral("Ancestor Retrieval"), ancestorRetrieval);
-    appendRow(item, QStringLiteral("Ancestor Fetch ID Only"),  toString(cfs.ancestorFetchIdOnly()));
+    appendRow(item, QStringLiteral("Ancestor Fetch ID Only"), toString(cfs.ancestorFetchIdOnly()));
     appendRow(item, QStringLiteral("Ancestor Attributes"), toString(cfs.ancestorAttributes()));
     appendRow(item, QStringLiteral("Ignore Retrieval Errors"), toString(cfs.ignoreRetrievalErrors()));
     model->appendRow(item);
@@ -642,7 +626,7 @@ void NotificationMonitor::saveToFile()
     }
 
     QJsonObject json;
-    auto ntfModel = qobject_cast<QStandardItemModel*>(m_ntfView->model());
+    auto ntfModel = qobject_cast<QStandardItemModel *>(m_ntfView->model());
     Q_ASSERT(ntfModel);
 
     QJsonArray rowArray;
